.. craft-archives documentation root file

Craft Archives
==============

Craft Archives is a Python package to manage interaction with software
archives on behalf of tools using the Craft Parts framework.

Craft Archives provides a set of common interfaces to define the locations
of software archives, install packages and verify their integrity.

The aim of this package is to provide a uniform, extensible set of interfaces
that other tools and packages can use to work with software archives.

This package is most useful for implementers of tools using the Craft Parts
framework that need to provide support for additional software archives.

.. toctree::
   :maxdepth: 1
   :hidden:

   tutorials/index
   howto/index
   reference/index
   explanation/index

.. grid:: 1 1 2 2

   .. grid-item-card:: :ref:`Tutorial <tutorial>`

      **Get started** with a hands-on introduction to Craft Archives

   .. grid-item-card:: :ref:`How-to guides <howto>`

      **Step-by-step guides** covering key operations and common tasks

.. grid:: 1 1 2 2
   :reverse:

   .. grid-item-card:: :ref:`Reference <reference>`

      **Technical information** about Craft Archives

   .. grid-item-card:: :ref:`Explanation <explanation>`

      **Discussion and clarification** of key topics

Project and community
=====================

Craft Archives is a member of the Canonical family. It's an open source project
that warmly welcomes community projects, contributions, suggestions, fixes
and constructive feedback.

* `Ubuntu Code of Conduct <https://ubuntu.com/community/code-of-conduct>`_.
* `Canonical contributor licence agreement
  <https://ubuntu.com/legal/contributors>`_.

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
